@@ -540,9 +540,13 @@ FilePs <- function(input, output, session, nfactor.limit = 20) {
     data.na <- data[-case.naomit]
     data.na$pscore <- NA
     data.na$iptw <- NA
+    caliper <- NULL
+    if (input$caliper > 0){
+      caliper <- input$caliper
+    }
 
     forms <- as.formula(paste(input$group_pscal, " ~ ", paste(input$indep_pscal, collapse = "+"), sep=""))
-    m.out <- MatchIt::matchit(forms, data = data.naomit[, .SD, .SDcols = c("ID.pscal2828", input$group_pscal, input$indep_pscal)], caliper = input$caliper, ratio = as.integer(input$ratio_ps))
+    m.out <- MatchIt::matchit(forms, data = data.naomit[, .SD, .SDcols = c("ID.pscal2828", input$group_pscal, input$indep_pscal)], caliper = caliper, ratio = as.integer(input$ratio_ps))
     pscore <- m.out$distance
     iptw <- ifelse(m.out$treat == levels(m.out$treat)[2], 1/pscore,  1/(1-pscore))
 
