@@ -476,7 +476,7 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
         yst.name <- paste(label.regress[variable == input$indep_km, var_label], "group")
         yst.lab <- paste(label.regress[variable == input$indep_km, var_label], paste(c(">", "\u2264"), input$cut5, sep=""))
       }
-      ylab <- ifelse(input$cumhaz, "Cumulative hazard", "Survival")
+      ylab <- ifelse(input$cumhaz, "Cumulative incidence", "Survival")
       return(list(res = res.km, ylab = ylab, yst.name = yst.name, yst.lab = yst.lab, data = data.km))
 
     } else{
@@ -523,7 +523,7 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
         yst.name <- paste(label.regress[variable == input$indep_km, var_label], "group")
         yst.lab <- paste(label.regress[variable == input$indep_km, var_label], paste(c(">", "\u2264"), input$cut5, sep=""))
       }
-      ylab = ifelse(input$cumhaz, "Cumulative hazard", "Survival")
+      ylab = ifelse(input$cumhaz, "Cumulative incidence", "Survival")
       return(list(res = res.km, ylab = ylab, yst.name = yst.name, yst.lab = yst.lab, data = data.design))
     }
   })
